import os
from qa.edit_distance import edit_dis
from flask import Flask, render_template, request


app = Flask(__name__)


@app.route('/askme', methods=['GET', 'POST'])
def validate():
    if request.method == "POST":
        # retrive answer from form
        result = request.form['question'].lower()
        # generate answer
        if result != "":
            predicted = edit_dis(result)
            return render_template('index.html', predicted=predicted)
    return render_template('index.html')


if __name__ == '__main__':
    app.run(host='0.0.0.0', port=int(os.getenv('PORT', 5000)))


import pandas as pd
from pathlib import Path

def readData(txt):
    # read txt and normalize
    data = pd.read_csv(txt, delimiter="\n", header=None)
    data[0] = data[0].apply(lambda x: str(x).lower())

    return data[0]


def generate_pairs():
    # create main dataframe
    col_names = ["Topic", "Question", "Answer"]
    df = pd.DataFrame(columns=col_names)
    # create pandas dataframes for files
    topics = readData("qa/dataset/Topics.txt")
    questions = readData("qa/dataset/Questions.txt")
    answers = readData("qa/dataset/Answers.txt")
    # create large data frame
    df["Topic"]=topics.apply(lambda x: str(x).lower())
    df["Question"]=questions.apply(lambda x: str(x).lower())
    df["Answer"]=answers.apply(lambda x: str(x).lower())

    return df

def convert_to_list(txt):
    """takes a text file and returns a list"""
    data = pd.read_csv(txt, delimiter="\n", header=None)
    return data.values.tolist()


import pandas as pd
from qa.parsedata import generate_pairs
from nltk.metrics import edit_distance
import argparse



def edit_dis(question):
    """Retrieves the similar question in the test data with a users question"""

    # retrive dataframe
    df = generate_pairs()

    # convert to list for modeling
    x = df.Question.tolist()
    y = df.Answer.tolist()

    x_index = -1  # initialize index for tracking index of similar question
    _val = 1000
    for i in range(len(x)):
        # calculate edit distance
        val_dis = edit_distance(question.split(), x[i].split())
        if(val_dis < _val):
            _val = val_dis
            x_index = i
    return y[x_index]
